Query

Struct Query 

pub struct Query { /* private fields */ }
Provides fluent API interfaces and result caching to simplify queries and operations.

Implementations

Source

impl Query

pub fn new(html: &str) -> Self

pub fn query(self, selector: &str) -> Self

Query nodes using a selector.

pub fn from(self, context: SelectionResult, selector: &str) -> Self

Query nodes from the specified context.

pub fn for_each<F>(self, f: F)

Execute a function for each selection result.

pub fn text(self) -> Option<String>

Get the result of the first text.

pub fn texts(self) -> Vec<String>

Get results of all texts.

pub fn node(self) -> Option<NodeHandle>

Get the result of the first node.

pub fn nodes(self) -> Vec<NodeHandle>

Get results of all nodes

pub fn result(self) -> InterpreterResult<SelectionResult>

Obtain the final query results.

pub fn then(self, selector: &str) -> Self

Use the query results as the context for another query.

pub fn clear_cache(self) -> Self

Clear cache.

pub fn count(self) -> usize

Get result count.

pub fn is_empty(self) -> bool

Check if the result is empty.